CheckItem class

Represents a single checkable item in the DynamicMultiCheck widget

Constructors

CheckItem({required String name, required String value, bool isChecked = false, String? id})
CheckItem.fromJson(Map<String, dynamic> json)
Creates a CheckItem from JSON
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
final
isChecked bool
getter/setter pair
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

copyWith({String? name, String? value, bool? isChecked}) CheckItem
Creates a copy of the CheckItem with updated values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the CheckItem to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override