DynamicMultiCheckProvider class
Provider class for managing CheckItems state
- Mixed-in types
Constructors
Properties
-
checkedItems
→ List<
CheckItem> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
-
items
→ List<
CheckItem> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
uncheckedItems
→ List<
CheckItem> -
no setter
Methods
-
addItem(
CheckItem item) → void - Add a new item
-
addItems(
List< CheckItem> items) → void - Add multiple items
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
clearAll(
) → void - Clear all items
-
clearChecked(
) → void - Clear only checked items
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
getAllItemsJson(
) → List< Map< String, dynamic> > - Get JSON representation of all items
-
getCheckedItemsJson(
) → List< Map< String, dynamic> > - Get JSON representation of checked items
-
initializeWith(
List< CheckItem> initialItems) → void - Initialize with default items
-
loadFromJson(
List< Map< jsonList) → voidString, dynamic> > - Load items from JSON
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeItem(
int index) → void - Remove an item by index
-
removeItemById(
String id) → void - Remove an item by id
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toggleItem(
int index) → void - Toggle check state of an item
-
toString(
) → String -
A string representation of this object.
inherited
-
updateItem(
int index, CheckItem newItem) → void - Update an item
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited